# FastAPI CRUD with dynamic routers

## Introduction

This is a simple CRUD application using FastAPI. The application uses dynamic routers to create routes for each model in the database.

## How to run

First, install the dependencies:

```bash

pip install -r requirements.txt

```
